# :mag_right: CSV-Compare
#### A python package for Jamf MacAdmins in mind

CSV-Compare allows you to find differences between two CSV files based on a specified column identifier. It provides a simple way to compare the contents of two CSV files and identify which records are present in one file but not in the other. 

# :construction: This project is currently under construction
> It has not yet been uploaded to pypi.org at present. Attempting to install via pip will not work presently.

